# History
* **1.0.5**
    * Added __main__ file to root directory to prevent error when starting via python3
* **1.0.4**
    * Corrected errors in documentation and git trees
* **1.0.3**
    * Added more documentation
    * New installation instructions
* **1.0.2**
    * Small documentation changes
* **1.0.1**
    * Fixed 'Module not recognised' bug
    * Added start time to beginning of scan process
    * Fixed verbose mode not printing negative results
* **1.0.0**
    * 1.0.0 full package release
